| check_dependencies | R Documentation |
Checks if dependencies can be loaded; names missing dependencies if not.
check_dependencies(..., verbosity = 0L)
... |
List or vector of strings defining namespaces to be checked |
verbosity |
Integer: Verbosity level. Note: An error will always printed if dependencies are missing. Setting this to FALSE stops it from printing "Dependencies check passed". |
Called for side effects. Aborts and prints list of missing dependencies, if any.
EDG
check_dependencies("base")
# Throws error:
try(check_dependencies("zlorbglorb"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.