| clean_colnames | R Documentation |
Clean column names by replacing all spaces and punctuation with a single underscore
clean_colnames(x)
x |
Character vector or matrix with colnames or any object with |
Character vector.
EDG
clean_colnames(iris)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.