printdf: Print data frame

View source: R/utils_print.R

printdfR Documentation

Print data frame

Description

Pretty print a data frame

Usage

printdf(
  x,
  pad = 0,
  spacing = 1,
  ddSci_dp = NULL,
  transpose = FALSE,
  justify = "right",
  colnames = TRUE,
  rownames = TRUE,
  column_fmt = highlight,
  row_fmt = gray,
  newline_pre = FALSE,
  newline = FALSE
)

Arguments

x

data frame

pad

Integer: Pad output with this many spaces.

spacing

Integer: Number of spaces between columns.

ddSci_dp

Integer: Number of decimal places to print using ddSci. Default = NULL for no formatting.

transpose

Logical: If TRUE, transpose x before printing.

justify

Character: "right", "left".

colnames

Logical: If TRUE, print column names.

rownames

Logical: If TRUE, print row names.

column_fmt

Formatting fn for printing column names.

row_fmt

Formatting fn for printing row names.

newline_pre

Logical: If TRUE, print a new line before printing data frame.

newline

Logical: If TRUE, print a new line after printing data frame.

Details

By design, numbers will not be justified, but using ddSci_dp will convert to characters, which will be justified. This is intentional for internal use.

Value

NULL invisibly

Author(s)

EDG

Examples

printdf(iris[1:6, ])

rtemis.core documentation built on April 22, 2026, 1:11 a.m.