| check_float0pos | R Documentation |
Checks if an input is a numeric vector containing non-negative
(>= 0) values and no NAs. It is designed to validate function arguments.
check_float0pos(x, allow_null = TRUE, arg_name = deparse(substitute(x)))
x |
Numeric vector. |
allow_null |
Logical: If TRUE, NULL values are allowed and return early. |
arg_name |
Character: Name of the variable for error messages. |
Called for side effects. Throws an error if checks fail.
EDG
check_float0pos(c(0, 0.5, 1))
# Allows integers since they are numeric and can be coerced to double without loss of information
check_float0pos(c(0L, 1L))
# Throws error:
try(check_float0pos(c(-1.5, 0, 1.5)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.