| check_floatpos | R Documentation |
Check positive float
check_floatpos(x, allow_null = TRUE, arg_name = deparse(substitute(x)))
x |
Numeric vector. |
allow_null |
Logical: If TRUE, NULL values are allowed and return early. |
arg_name |
Character: Name of the variable for error messages. |
Checking with is.numeric() allows integer inputs as well, which should be ok since it is
unlikely the function that consumes this will enforce double type only, but instead is most
likely to allow implicit coercion from integer to numeric.
Called for side effects. Throws an error if checks fail.
EDG
check_floatpos(c(0.5, 1.5))
# Allows integers since they are numeric and can be coerced to double without loss of information
check_floatpos(c(1L, 3L))
# Throws error:
try(check_floatpos(c(-1.5, 0.5, 1.5)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.