| optional | R Documentation |
Creates an S7 union type that allows for the specified type or NULL.
optional(type)
type |
S7 base class or S7 class. |
An S7 union type that allows for the specified type or NULL.
EDG
# Create an optional character type
optional(S7::class_character)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.