| printdf | R Documentation |
Pretty print a data frame
printdf(
x,
pad = 0,
spacing = 1,
ddSci_dp = NULL,
transpose = FALSE,
justify = "right",
colnames = TRUE,
rownames = TRUE,
column_fmt = highlight,
row_fmt = gray,
newline_pre = FALSE,
newline = FALSE
)
x |
data frame |
pad |
Integer: Pad output with this many spaces. |
spacing |
Integer: Number of spaces between columns. |
ddSci_dp |
Integer: Number of decimal places to print using ddSci. Default = NULL for no formatting. |
transpose |
Logical: If TRUE, transpose |
justify |
Character: "right", "left". |
colnames |
Logical: If TRUE, print column names. |
rownames |
Logical: If TRUE, print row names. |
column_fmt |
Formatting fn for printing column names. |
row_fmt |
Formatting fn for printing row names. |
newline_pre |
Logical: If TRUE, print a new line before printing data frame. |
newline |
Logical: If TRUE, print a new line after printing data frame. |
By design, numbers will not be justified, but using ddSci_dp will convert to characters, which will be justified. This is intentional for internal use.
NULL invisibly
EDG
printdf(iris[1:6, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.